DM "CLEAR OUTPUT;CLEAR LOG";
*__________________________________________________________________________________________________
Project: HCBS Quality Measures built under the Money Follows the Person (MFP) Contract
Program: 02_HCBS_PQI_INPUT.sas

Purpose: Read-in Medicare (MedPAR) and Medicaid (MAX) discharges in preparation for running the 03_HCBQ_PQSAS1 program. 
         In general, this program removes unneeded discharges and cleans the MAX and MedPAR data.

Authors: HXU and XLIN at Mathematica Policy Research 10/6/2014
Inputs:  1)denominator file output from 01_Prep_Denominator: HCBS_PQI_DENOM
         2)MAX discharges for the HCBS population in the denominator file
         3)MedPAR discharges for the HCBS population in the denominator file
         
Output:  HCBS_PQI_INPUT.sas7bdat

Note:    1) This program depends on the CONTROL_PSIInput.SAS program, which specifies file pathways and macros.
         2) In the development of these programs, the MAX data did not have reliable hospital ID or POA information.
            For users with the same issue, we include our default work-arounds.
         3) The unique identifier for each HCBS user is MSIS_ID and STATE combinations
___________________________________________________________________________________________________;
OPTIONS NOCENTER FORMDLIM='=' LS=256 ORIENTATION=LANDSCAPE OBS=MAX;

FILENAME CONTROL 'CONTROL.SAS'; *<===USER MUST modify;
%INCLUDE CONTROL;

LIBNAME IN1 "&PATH."; *denominator file from 01 program;
LIBNAME IN2 "&PATH."; *Medicaid(MAX) and Medicare (MedPAR) files;
LIBNAME OUT "&PATH."; *output HCBS_PQI_INPUT;

%LET PatData= IN1.HCBS_PQI_DENOM;         *Patient-level file, from 01_Prep_Denominator.sas;
%LET MaxData= IN2.max;                    *MAX Data: Discharge-level file - Discharges from Medicaid, user modify;
%LET MedPar = IN2.medpar;                 *MedPar:   Discharge-level file -Discharges from Medicare, user modify;
%LET OUTFILE= OUT.HCBS_PQI_INPUT;         *user modify;
 
******************************************************************************************************************
Step1: Read-in denominator finder file
******************************************************************************************************************;
PROC SORT DATA=&PATDATA.(KEEP=MAX_STATE MSIS_ID CALENDAR_YR
                              A_DUAL A_RACE A_AGE A_FEMALE
                              HOSPICE_START HOSPICE_END 
                              HCBS_USER_1-HCBS_USER_12
                              MAX_HCBS_ENROLL_1-MAX_HCBS_ENROLL_12
                              EL_MDCR_DUAL_MO_1 -EL_MDCR_DUAL_MO_12
                         RENAME=(MAX_STATE=STATE)) 
          OUT=PATSORTED NODUPKEY;
   BY STATE MSIS_ID;
RUN;


******************************************************************************************************************
Step2: Read-in MAX and MedPAR discharge files 
******************************************************************************************************************;
%MACRO Discharges;
TITLE4 "Medicaid data";
DATA MAX;
   LENGTH  PR1-PR&MCaid_NPR. DX1-DX&MCaid_NDX. $8 DXPOA1-DXPOA&MCaid_NDX. $1 /*HOSPID $6*/; 
   SET &MAXDATA.(RENAME=(%DO I = 1 %TO &MCaid_NDX.; DIAG_CD_&I. =DX&I. %END;
                         %DO I = 1 %TO &MCaid_NPR.; PRCDR_CD_&I.=PR&I. %END;
                         DRG_REL_GROUP     = DRG
                         MAX_STATE         = STATE
                         MAX_HIC           = HICNO                          
                         PATIENT_STATUS_CD = DDEST));
     
      *MAX 2010 data on which this program was built does not have the HOSPID, so we set it as blank here;
      *If MAX is missing a provider ID, we suggest using NPI or the closest equivalent;
      /*HOSPID =' ';*/

      IF SRVC_BGN_DT NOT IN (0,.) THEN ADMIT=INPUT(PUT(SRVC_BGN_DT,Z8.),YYMMDD10.); ELSE ADMIT=.;
      IF SRVC_END_DT NOT IN (0,.) THEN DISCH=INPUT(PUT(SRVC_END_DT,Z8.),YYMMDD10.); ELSE DISCH=.;
     
      PAY1 = 2;/*Medicaid*/

      *The MAX 2010 data on which this program was built did not have POA information;
      *If POA is unavailable in your file, the user can specify all POA = Y below;
     /* %DO I = 1 %TO &MCaid_NDX.; DXPOA&I.='Y'; %END;*/
RUN;

TITLE4 "Medicare data";
DATA MEDPAR;
   LENGTH  PR1-PR&MCare_NPR. DX1-DX&MCare_NDX. $8 DXPOA1-DXPOA&MCare_NDX. $1 HOSPID $6; 
   SET &MedPar.(RENAME =(%DO I = 1 %TO &MCare_NDX.; MEDPAR_DGNS_CD&I.=DX&I. MEDPAR_POA_DGNS_IND_CD&I.=DXPOA&I. %END;  
                         %DO I = 1 %TO &MCare_NPR.; MEDPAR_SRGCL_PRCDR_CD&I.=PR&I. %END;    
                         MEDPAR_DRG_CD           = DRG  
                         MAX_STATE               = STATE 
                         MAX_HIC                 = HICNO   
                         MEDPAR_DSCHRG_DSTNTN_CD = DDEST   
                         MEDPAR_IP_ADMSN_TYPE_CD = ADM_TYPE));

      *Concatenate these three variables to create a new variable called hospid (equivalent to the Medicare CCN)
                         MEDPAR_PRVDR_STATE_CD,MEDPAR_PRVDR_NUM_3RD_CD,MEDPAR_PRVDR_NUM_SRL_CD;

      HOSPID=PUT(MEDPAR_PRVDR_STATE_CD,Z2.)||MEDPAR_PRVDR_NUM_3RD_CD||MEDPAR_PRVDR_NUM_SRL_CD;

      IF MEDPAR_ADMSN_DT  NOT IN (0,.) THEN ADMIT = DATEJUL(MEDPAR_ADMSN_DT);  ELSE ADMIT=.;
      IF MEDPAR_DSCHRG_DT NOT IN (0,.) THEN DISCH = DATEJUL(MEDPAR_DSCHRG_DT); ELSE DISCH=.; 

      PAY1 = 1; /*Medicare*/

      *Create SNF (Skilled Nursing Facility) flag ;

      IF '5000'<=SUBSTR(HOSPID,3,4)<='6499' THEN SNF=1;
      ELSE SNF=0;

      
      /*Remove the non-acute care claims here, since they are billed daily,
      therefore they could have the multiple claims for one hospital stay.
      
      a. Keep records for Provider IDs (PROV) if they have:
         - A 0 in the 3rd digit OR a 13 in 3rd/4th digit AND
         - A blank special unit indicator (UNIT)

      b. Drop other claims:
         IF SUBSTR(PROV,5,1) = V ; *** VA claims; 
         IF SUBSTR(PROV,6,1) IN (E, F); *** Foreign provider claims;

      c. Identify/drop other non FFS claims *changes in red added 1/28/14 by N. Bhat;
         Create a MCO_claim flag that is = 1 if:
         IF GHOPAID = 1; *** MA paid claims flag;  OR
         IF IMEPAY GT 0 ANDIMEPAY = DRGPAY; *** Some Medicare Advantage claims have teaching pay = total drg payment; OR 
         IF FY=2012 or 2013
         IF CLMTYPE IN( 61, 62, 63, 64);*/

      IF SUBSTR(STRIP(HOSPID),3,1)='0'  THEN FLAG1=1;
      IF SUBSTR(STRIP(HOSPID),3,2)='13' THEN FLAG2=1;
      IF MEDPAR_PRVDR_NUM_SPCL_UNIT_CD=' '  THEN FLAG3=1;
      IF SUBSTR(STRIP(UPCASE(HOSPID)),5,1)='V'  THEN FLAG4=1;
      IF SUBSTR(STRIP(UPCASE(HOSPID)),6,1) IN ('E','F') THEN FLAG5=1;

      IF (FLAG1=1 OR FLAG2=1) AND FLAG3=1 THEN ACUTE=1;ELSE ACUTE=0;
      IF FLAG4=1 OR FLAG5=1 THEN N_ACUTE=1;ELSE N_ACUTE=0;
RUN;

*Append Medicaid and Medicare together;
DATA MAX_MEDPAR;
   SET MAX(IN=A    KEEP=MSIS_ID DX1-DX&MCaid_NDX. DXPOA1-DXPOA&MCaid_NDX. PR1-PR&MCaid_NPR. DRG STATE HICNO 
                        HOSPID DDEST ADMIT DISCH PAY1) 
       MEDPAR(IN=B KEEP=MSIS_ID DX1-DX&MCare_NDX. DXPOA1-DXPOA&MCare_NDX. PR1-PR&MCare_NPR. DRG STATE HICNO 
                        HOSPID DDEST ADMIT DISCH PAY1 
                        ADM_TYPE SNF ACUTE N_ACUTE);
   LENGTH FROM $6;
   IF A THEN FROM='MAX';
   IF B THEN FROM='MEDPAR';
   LABEL FROM="Indicate if the discharge is from MAX or MedPar data";
RUN;

TITLE5 "Check the MAX and MedPAR stacking";
PROC FREQ DATA=MAX_MEDPAR;
   TABLES FROM FROM*(DXPOA1-DXPOA&NDX.)/MISSING LIST;
RUN;

PROC SORT DATA=MAX_MEDPAR;
   BY STATE MSIS_ID;
RUN;
%MEND Discharges;
%Discharges;

***************************************************************************
Step3: Clean data, removing non-acute, SNF, and MAX records for Duals
***************************************************************************;
DATA PAT_MAX_MEDPAR_ALL;
   MERGE PATSORTED(IN=A) MAX_MEDPAR(IN=B);
   BY STATE MSIS_ID;
   IF A THEN IN_PAT=1;
   IF B THEN IN_MAX_MEDPAR=1;
RUN;
TITLE4 "Check the merging of Patient data and MAX_MEDPAR discharge-level file";
PROC FREQ DATA=PAT_MAX_MEDPAR_ALL;
   TABLES IN_PAT*IN_MAX_MEDPAR 
          IN_PAT*IN_MAX_MEDPAR*FROM*SNF/MISSING LIST;
RUN;

*Retain only those MAX or MedPAR discharges in the FINDERs file based on STATE MSIS_ID variables;
DATA PAT_MAX_MEDPAR(DROP=IN_PAT IN_MAX_MEDPAR);
   SET PAT_MAX_MEDPAR_ALL;
   IF IN_PAT=1 AND IN_MAX_MEDPAR=1;
RUN;

DATA PAT_MAX_MEDPAR_TMP;
   SET PAT_MAX_MEDPAR;

   *Flag MAX claims for the patient who is dual in the month the discharge occured (that is admitted in that month). 
    00 means non-dual, any values other than 00 indicate dual;
   %MAXDUAL_FLAG_POP;

   *Excludes hospitalization occuring outside of HCBS use or enrollment.
    Excludes records where HCBS_IP is not equal to 1;
   %HCBS_IP_POP;

   *Create the variables needed in the software;
   IF A_FEMALE=1 THEN SEX=2;
   ELSE IF A_FEMALE=0 THEN SEX=1;
   ELSE SEX=.;

   AGEDAY=.; /*age and ageday   AGE COMES WITH DATA, AGEDAYS SET TO MISSING*/
   IF DISCH^=. OR ADMIT^=. THEN  LOS= (DISCH -ADMIT)+1; *IN MEDPAR: IF DISCH^=. THEN LOS= (DISCH -ADMIT)+1;
   IF DISCH NOT IN (0,.) THEN DO;
      YEAR= YEAR(DISCH);
      DQTR= QTR(DISCH);
   END;
   ELSE DO;
      YEAR=.;
      DQTR=.;
   END;
      
   /*RECODE RACE BASED label for varaible A_Race: 1=Wh/ 2=Bl/ 3=NatA/ 4=Asn/ 5=PI/ 6=H/ 7=O*/
   *Note that this variable is not used in these programs;
   IF       A_RACE = 1 THEN RACE = 1;
   ELSE IF  A_RACE = 2 THEN RACE = 2;
   ELSE IF  A_RACE = 6 THEN RACE = 3;
   ELSE IF  A_RACE = 4 THEN RACE = 4;
   ELSE IF  A_RACE = 3 THEN RACE = 5;
   ELSE RACE= 6;/*6=OTHER*/

   /*Recode discharge disposition;
   *Use specifications at http://hcup-us.ahrq.gov/db/vars/siddistnote.jsp?var=dispuniform;*/
   IF  DDEST IN (1,21,71,72) THEN DISP = 1;
   ELSE IF DDEST IN (2,5,9,43,66) THEN DISP = 2; 
   ELSE IF DDEST IN (3,4,51,61,62,63,64,65,70) THEN DISP = 5; 
   ELSE IF DDEST IN (6,8,50) THEN DISP = 6;
   ELSE IF DDEST = 7 THEN DISP = 7;
   ELSE IF DDEST IN (20) THEN DISP = 20;
   ELSE IF DDEST IN (40,41,42,99) THEN DISP = 99;
   ELSE DISP = .;

   /*State and county not used in analysis, but must be present on file otherwise the record will be dropped.*/
   SSA_CNTY ='99999';/* fill to indicate missing;*/
   PSTCO = 99999;
   PAY2 = .;
 
  /*DRG version depends on discharge date, with changes implemented Oct 1 2007.
    Set drgver, DNR, and MDC to missing[.]. The 03_HCBS_PQSAS1 program assigns the the correct value.*/
   DISCWT=1;
   DRGVER= .;
   DNR = .;
   MDC=.;
   POINTOFORIGINUB04=.;
   ASOURCE=.;
   ATYPE =.;
   MORT30 =.;
RUN;

*Drop any MAX discharges for duals and SNF and non-acute discharges. Failure to drop here iwill impact the criteria below;
DATA PAT_MAX_MEDPAR_TMP2 DELETED_DISCHARGES1;
   SET PAT_MAX_MEDPAR_TMP;
   IF MAXDUAL_FLAG=1 OR SNF=1 OR ACUTE=0 OR N_ACUTE=1 THEN OUTPUT DELETED_DISCHARGES1;
   ELSE OUTPUT PAT_MAX_MEDPAR_TMP2;
RUN;

***************************************************************************
Step4: Identify duplicate discharges
***************************************************************************;

/* This step sorts the discharges to create "lag" variables that identify the values of admit and discharge date,
        hospital ID, and primary diagnosis on the previous record. 
  This information is then used to identify and remove duplicates*/
PROC SORT DATA=PAT_MAX_MEDPAR_TMP2 OUT=PQ_MSIS;
   BY STATE MSIS_ID ADMIT DISCH DX1 DESCENDING FROM ; 
RUN;

DATA PQ1_MSIS_3;
   LENGTH DUPLICATE $4  LAG_DX1 $9 LAG_FROM $6;
   SET PQ_MSIS ;
   BY STATE MSIS_ID ADMIT DISCH DX1 DESCENDING FROM ;

     LAG_DISCH=LAG1(DISCH);
     LAG_ADMIT=LAG1(ADMIT);
     LAG_DX1=LAG1(DX1);
     LAG_FROM=LAG1(FROM);

     IF first.MSIS_ID THEN DO;
     LAG_DISCH=.;
     LAG_ADMIT=.;
     LAG_DX1='';
     LAG_FROM='';
     END;

/* Drop duplicate if there is a match on admit, discharge, and hospital ID. Prioritize dropping Medicaid records.  */
     
    IF (LAG_ADMIT=ADMIT and LAG_DISCH=DISCH and LAG_DX1=DX1) 
    THEN DO;
        DUPLICATE='Drop'; 
        DUPLICATE_CHECK = 1;
    END;
    ELSE  DO;
        DUPLICATE='Keep';
        DUPLICATE_CHECK= 0 ;
    END;

    FORMAT LAG_DISCH LAG_ADMIT YYMMDD10.;

RUN;

*Sort dataset containing dual flags and if bene has a value of 1 on any record indicating a dropped record,
   retain that value on all records for that bene;
PROC SORT DATA=PQ1_MSIS_3 OUT=PQ1_MSIS_3_SORT;
   BY STATE MSIS_ID DESCENDING DUPLICATE_CHECK;
RUN;

*Set the sorted dataset and retaing the flag indicating if a bene had any dual records marked as drop. If a bene
 had any records marked as dual drop, set the DUAL_CHK flag = 1 for all records for that bene;
DATA PQ1_MSIS_3_FINAL;
   SET PQ1_MSIS_3_SORT;
   BY STATE MSIS_ID DESCENDING DUPLICATE_CHECK;
   RETAIN DUAL_CHK;
   IF FIRST.MSIS_ID THEN DUAL_CHK=DUPLICATE_CHECK;
RUN;

TITLE4 "Check DUPLICATE";
PROC FREQ DATA=PQ1_MSIS_3_FINAL ;
   TABLES DUPLICATE/MISSING LIST;
RUN;

PROC SORT DATA=PQ1_MSIS_3_FINAL OUT=PQ_MSIS_3_FINAL_SORT;
   BY STATE MSIS_ID ADMIT DISCH DESCENDING FROM HOSPID ;
RUN;

***************************************************************************
Step6: Identify transfers
***************************************************************************;

/* If the admission date is the same as the previous discharge date, this is a same-day readmission.
        This is how we define and remove transfers.
*/

DATA MSIS_TEMP;
  SET PQ_MSIS_3_FINAL_SORT (DROP=LAG_DISCH LAG_ADMIT LAG_DX1 LAG_FROM);
  BY STATE MSIS_ID ADMIT DISCH DESCENDING FROM HOSPID;
  /* CREATE A FIELD WHICH CONTAINS THE VALUE FROM THE PREVIOUS RECORD */
     LAG_DISCH=LAG1(DISCH);
     LAG_ADMIT=LAG1(ADMIT);
     LAG_HOSPID=LAG1(HOSPID);
     /* Initailize variables for first MSIS_ID record */
     IF first.MSIS_ID THEN DO;
     LAG_DISCH=.;
     LAG_ADMIT=.;
     LAG_HOSPID=' ';
     DISCH_TOT=0;
     END;

     DISCH_TOT+1; /* Note: DISCH_TOT contains transfers as the logic required to determine transfers includes checking
                           that the number of total discharges is GE 2. This field is only used in determining transfers.
                           a final TOTAL_DISCH field is created in datastep below after tranfers and duals are removed */
     
    IF ADMIT=LAG_DISCH AND HOSPID^=LAG_HOSPID THEN ADMIT_DISCH_FLAG='Y';
    ELSE ADMIT_DISCH_FLAG='N';

    FROM=UPCASE(FROM);
     
    FORMAT DISCH ADMIT LAG_DISCH LAG_ADMIT YYMMDD10.;
RUN;


/* SORT THE ABOVE DATASET BY STATE AND MSIS_ID AND DESCENDING DISCH_TOT. THE DESCENDING DISCH_TOT VALUES WILL 
   ALLOW THE GREATEST VALUE OF DISCH_TOT TO BE THE FIRST RECORD PER STATE AND MSIS_ID COMBINATION */
PROC SORT DATA=MSIS_TEMP OUT=MSIS_TEMP_SORT;
   BY STATE MSIS_ID DESCENDING DISCH_TOT DESCENDING FROM;
RUN;

/* CREATE TOTAL_DISCH_TEMP FIELD WHICH CONTAINS THE HIGHEST VALUE OF DISCH_TOT PER MSIS_ID/STATE. IF THIS VALUE
   IS OVER 2 AND THE ADMIT_DISCH_FLAG CREATED ABOVE (ADMIT=PREV_DISCH) IS Y THEN FLAG THE RECORD AS A TRANSFER.*/
DATA DISCH_CHECK;
   SET MSIS_TEMP_SORT;
   BY STATE MSIS_ID DESCENDING DISCH_TOT DESCENDING FROM;
   RETAIN TOT_DISCH_TEMP;
   IF FIRST.MSIS_ID THEN TOT_DISCH_TEMP=DISCH_TOT;
 
   IF (TOT_DISCH_TEMP GE 2) AND ADMIT_DISCH_FLAG='Y' THEN TRANSFER=1;
   ELSE TRANSFER=0;
RUN;

/*  In cases where there are more than 1 record with same ADMIT and DISCH, remove
   second record if first record marked as transfer was MEDPAR. Note, these are similar to dual records.  */
PROC SORT DATA=DISCH_CHECK OUT=DISCH_CHECK_SORT ;
   BY STATE MSIS_ID ADMIT DISCH DESCENDING FROM;
RUN;

/* SET DATA BY ADMIT, DISCH, AND DESCENDING FROM SO MEDPAR IS BEFORE MAX RECORD. IF THE PREVIOUS RECORD ADMIT=
   CURRENT RECORD ADMIT, PREVIOUS RECORD DISCH=DISCH, PREVIOUS RECORD IS MEDPAR AND PREVIOUS RECORD IS MARKED AS TRANSFER
   THEN MARK MAX RECORD AS TRANSFER */
DATA DISCH_CHECK_2;
   LENGTH LAG_FROM $6;
   SET DISCH_CHECK_SORT;
   BY STATE MSIS_ID ADMIT DISCH DESCENDING FROM;

     LAG_FROM=LAG1(FROM);
     LAG_TRANSFER=LAG1(TRANSFER);

     IF first.MSIS_ID THEN DO;
     LAG_FROM='';
     LAG_TRANSFER=.;
     END;

     /*Note: used orignal lag ADMIT and DISCH values as created in datastep above. Did check by recreating lag ADMIT
             and lag DISCH and results were the same. */

   IF (LAG_ADMIT=ADMIT and LAG_DISCH=DISCH AND LAG_FROM='MEDPAR' AND LAG_TRANSFER=1) THEN DO;
    TRANSFER = 1;
    RESET_TRANSFER=1;
END;
RUN;


/*********************************************************************/
/*  Repeat for MedPAR
/*********************************************************************/
/* SORT THE ABOVE DATASET AND PROCEED WITH SAME STEPS FOR THE HICNO ON EACH RECORD */
PROC SORT DATA=DISCH_CHECK_2 OUT=PQ_HICNO (DROP=RESET_TRANSFER LAG_DISCH LAG_ADMIT LAG_FROM LAG_TRANSFER);
   BY HICNO ADMIT DISCH DESCENDING FROM;
RUN;

/* CREATE THE DISCH_TOT FIELD WHICH WILL BE A COUNTER OF ALL DISCHARGES PER MSIS_ID/STATE. THIS IS AFTER DUALS HAVE BEEN REMOVED.
   CREATE LAG FIELDS WHICH RETAIN THE VALUE OF DISCHARGE, HOSPITAL_ID, AND ADMIT OF THE PREVIOUS RECORD.
   IF THE ADMIT FIELD ON A RECORD IS THE SAME AS THE PREVIOUS RECORDS DISCHARGE VALUE THEN MARK THE ADMIT_DISCH_FLAG WITH Y.
*/
DATA HICNO_TEMP;
  SET PQ_HICNO ;
  BY HICNO ADMIT DISCH DESCENDING FROM ;
  IF HICNO NE '' THEN DO;

     LAG_DISCH=LAG1(DISCH);
     LAG_ADMIT=LAG1(ADMIT);

     IF first.HICNO THEN DO;
     LAG_DISCH=.;
     LAG_ADMIT=.;
     DISCH_TOT_HIC=0;
     END;

     DISCH_TOT_HIC+1;  /* Note: DISCH_TOT_HIC contains transfers as the logic required to determine transfers includes checking
                           that the number of total discharges is GE 2. This field is only used in determining transfers.
                           a final TOTAL_DISCH field is created in datastep below after tranfers and duals are removed */

     IF ADMIT=LAG_DISCH THEN ADMIT_DISCH_FLAG_HIC='Y';
     ELSE ADMIT_DISCH_FLAG_HIC='N';

     END;

     FORMAT DISCH ADMIT LAG_DISCH LAG_ADMIT YYMMDD10.;

RUN;

/* SORT THE ABOVE DATASET BY HICNO AND DESCENDING DISCH_TOT. THE DESCENDING DISCH_TOT VALUES WILL 
   ALLOW THE GREATEST VALUE OF DISCH_TOT TO BE THE FIRST RECORD PER HICNO */

PROC SORT DATA=HICNO_TEMP OUT=HICNO_TEMP_SORT;
   BY HICNO DESCENDING DISCH_TOT_HIC DESCENDING FROM;
RUN;

/* CREATE TOTAL_DISCH_HIC FIELD WHICH CONTAINS THE HIGHEST VALUE OF DISCH_TOT_HIC PER HICNO. IF THIS VALUE
   IS OVER 2 AND THE ADMIT_DISCH_FLAG CREATED ABOVE (ADMIT=PREV_DISCH) IS Y THEN FLAG THE RECORD AS A TRANSFER.
 */

DATA DISCH_CHECK_HICNO;
   SET HICNO_TEMP_SORT;
   BY HICNO DESCENDING DISCH_TOT_HIC DESCENDING FROM;
   RETAIN TOT_DISCH_HIC_TEMP;
   IF FIRST.HICNO then  TOT_DISCH_HIC_TEMP=DISCH_TOT_HIC;
   IF TRANSFER ne 1 AND HICNO NE '' then do; 
      IF (TOT_DISCH_HIC_TEMP GE 2) AND ADMIT_DISCH_FLAG_HIC='Y' THEN TRANSFER=1;
      ELSE TRANSFER=0;
   end;
RUN;

/* COUNT OF TRANFERS AT SECOND PASS BY HICNO */
PROC FREQ DATA=DISCH_CHECK_HICNO;
   TABLES TRANSFER/MISSING LIST;
   TITLE4 'SPEC 02: COUNT OF TRANFERS AT SECOND PASS BY HICNO';
RUN;
 
/* In cases where there are more than 1 record with same ADMIT and DISCH, remove
   second record if first record marked as transfer was MEDPAR. Note, these are similar to dual records. */

PROC SORT DATA=DISCH_CHECK_HICNO OUT=DISCH_CHECK_HICNO_SORT;
   BY HICNO ADMIT DISCH DESCENDING FROM;
RUN;

DATA DISCH_CHECK_HICNO_2;
LENGTH LAG_FROM $6;
SET DISCH_CHECK_HICNO_SORT;
BY HICNO ADMIT DISCH DESCENDING FROM;

     LAG_FROM=LAG1(FROM);
     LAG_TRANSFER=LAG1(TRANSFER);

     IF first.HICNO THEN DO;
     LAG_FROM='';
     LAG_TRANSFER=.;
     END;

IF (LAG_ADMIT=ADMIT and LAG_DISCH=DISCH AND LAG_FROM='MEDPAR' AND LAG_TRANSFER=1) THEN DO;
    TRANSFER = 1;
    RESET_TRANSFER=1;
END;
RUN;


***************************************************************************
Step7: Drop records outside of HCBS use/enrollment, duplicates, transfers, records with LOS <0 or > 365.
***************************************************************************;
DATA DISCH_CHECK_HICNO_2_FINAL DELETED_DISCHARGES2;
   SET DISCH_CHECK_HICNO_2(RENAME=A_AGE=AGE);
   *create HOSPICE_IP;
   IF HOSPICE_START<ADMIT<HOSPICE_END THEN HOSPICE_IP=1;
   ELSE HOSPICE_IP=0;

   IF HCBS_IP^=1 OR (LOS<=0 OR LOS>365) OR DUPLICATE='Drop' OR TRANSFER=1 THEN OUTPUT DELETED_DISCHARGES2;  
   ELSE OUTPUT DISCH_CHECK_HICNO_2_FINAL;
RUN;

***************************************************************************
Step8: Create output file for 03_ HCBS_PQSAS1 program
***************************************************************************;

DATA &OUTFILE.;
   SET DISCH_CHECK_HICNO_2_FINAL
  (KEEP=MSIS_ID STATE 
        DRG DRGVER MDC SEX AGE AGEDAY PSTCO A_DUAL
        RACE YEAR DQTR PAY1 PAY2 
        ASOURCE POINTOFORIGINUB04 ATYPE                        
        DX1-DX&NDX. DXPOA1-DXPOA&NDX. PR1-PR&NPR. DISCWT
        HICNO ADMIT DISCH HOSPID FROM HOSPICE_IP); 
   KEY = _N_; 
RUN;

TITLE5 "&OUTFILE.";
PROC MEANS DATA=&OUTFILE. N NMISS MIN MAX SUM MEAN STD;
RUN;

PROC CONTENTS DATA=&OUTFILE.;RUN;

/*The End*/


